oauth.client

OAuth client library for Clojure.

OAuth client library for Clojure.
raw docstring

access-tokenclj

(access-token consumer request-token)
(access-token consumer request-token verifier)

Exchange a request token for an access token. With two arguments, this function follows OAuth 1.0. With three arguments, it uses a verifier.

Exchange a request token for an access token.
With two arguments, this function follows OAuth 1.0.
With three arguments, it uses a verifier.
sourceraw docstring

authorization-headerclj

(authorization-header oauth-params)
(authorization-header oauth-params realm)

Format OAuth credentials for the Authorization HTTP header.

Format OAuth credentials for the Authorization HTTP header.
sourceraw docstring

build-oauth-token-requestclj

(build-oauth-token-request consumer
                           uri
                           unsigned-oauth-params
                           &
                           [extra-params token-secret])

Build an OAuth request.

Build an OAuth request.
sourceraw docstring

build-requestclj

(build-request oauth-params & [form-params])

Build a request from prepared parameters.

Build a request from prepared parameters.
sourceraw docstring

build-xauth-access-token-requestclj

(build-xauth-access-token-request consumer username password nonce timestamp)
(build-xauth-access-token-request consumer
                                  {token :oauth_token
                                   secret :oauth_token_secret}
                                  username
                                  password
                                  nonce
                                  timestamp)
source

credentialsclj

(credentials consumer
             token
             token-secret
             request-method
             request-uri
             &
             [request-params])

Return authorization credentials for protected resources. The returned map contains key-value pairs. Add them to the Authorization HTTP header or as query parameters in the request.

Return authorization credentials for protected resources. The returned map
contains key-value pairs. Add them to the Authorization HTTP header or as query
parameters in the request.
sourceraw docstring

form-decodeclj

(form-decode s)

Parse form-encoded bodies in OAuth responses.

Parse form-encoded bodies in OAuth responses.
sourceraw docstring

make-consumerclj

(make-consumer key secret request-uri access-uri authorize-uri signature-method)

Make a consumer struct map.

Make a consumer struct map.
sourceraw docstring

post-request-body-decodedclj

(post-request-body-decoded url & [req])
source

refresh-tokenclj

(refresh-token consumer expired-token)
(refresh-token consumer expired-token verifier)

Exchange an expired access token for a new access token.

Exchange an expired access token for a new access token.
sourceraw docstring

request-tokenclj

(request-token consumer)
(request-token consumer callback-uri)
(request-token consumer callback-uri extra-params)

Get a request token for the Consumer.

Get a request token for the Consumer.
sourceraw docstring

user-approval-uriclj

(user-approval-uri consumer token)
(user-approval-uri consumer token extra-params)

Build the URI for the Service Provider. The User approves the Consumer's access to the User's account there. You can include extra parameters in a map.

Build the URI for the Service Provider. The User approves the Consumer's
access to the User's account there. You can include extra parameters in a map.
sourceraw docstring

xauth-access-tokenclj

(xauth-access-token consumer username password)

Request an xAuth access token with a username and password.

Request an xAuth access token with a username and password.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries