OAuth client library for Clojure.
OAuth client library for Clojure.
(access-token consumer request-token)(access-token consumer request-token verifier)Exchange a request token for an access token. With two arguments, this function follows OAuth 1.0. With three arguments, it uses a verifier.
Exchange a request token for an access token. With two arguments, this function follows OAuth 1.0. With three arguments, it uses a verifier.
(authorization-header oauth-params)(authorization-header oauth-params realm)Format OAuth credentials for the Authorization HTTP header.
Format OAuth credentials for the Authorization HTTP header.
(build-oauth-token-request consumer
uri
unsigned-oauth-params
&
[extra-params token-secret])Build an OAuth request.
Build an OAuth request.
(build-request oauth-params & [form-params])Build a request from prepared parameters.
Build a request from prepared parameters.
(build-xauth-access-token-request consumer username password nonce timestamp)(build-xauth-access-token-request consumer
{token :oauth_token
secret :oauth_token_secret}
username
password
nonce
timestamp)(credentials consumer
token
token-secret
request-method
request-uri
&
[request-params])Return authorization credentials for protected resources. The returned map contains key-value pairs. Add them to the Authorization HTTP header or as query parameters in the request.
Return authorization credentials for protected resources. The returned map contains key-value pairs. Add them to the Authorization HTTP header or as query parameters in the request.
(form-decode s)Parse form-encoded bodies in OAuth responses.
Parse form-encoded bodies in OAuth responses.
(make-consumer key secret request-uri access-uri authorize-uri signature-method)Make a consumer struct map.
Make a consumer struct map.
(refresh-token consumer expired-token)(refresh-token consumer expired-token verifier)Exchange an expired access token for a new access token.
Exchange an expired access token for a new access token.
(request-token consumer)(request-token consumer callback-uri)(request-token consumer callback-uri extra-params)Get a request token for the Consumer.
Get a request token for the Consumer.
(user-approval-uri consumer token)(user-approval-uri consumer token extra-params)Build the URI for the Service Provider. The User approves the Consumer's access to the User's account there. You can include extra parameters in a map.
Build the URI for the Service Provider. The User approves the Consumer's access to the User's account there. You can include extra parameters in a map.
(xauth-access-token consumer username password)Request an xAuth access token with a username and password.
Request an xAuth access token with a username and password.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |